@@ -909,6 +909,18 @@ class DaxManager(object):
 
 
 def run_upload_thread(logfile, xnat_host, pindex, alabel, pcount, resdir):
+    # Confirm that assessor is still in queue,
+    # it could have been uploaded by a different thread
+    if not os.path.exists(os.path.join(resdir, alabel)):
+        LOGGER.info(f'skipping, already uploaded:{alabel}')
+        return
+
+    # Pre-check for lock file to skip already uploading
+    if os.path.exists(os.path.join(
+        resdir, 'FlagFiles', f'{alabel}_Upload.txt')):
+        LOGGER.info(f'skipping, lock file found:{alabel}')
+        return
+
     logging.getLogger('dax').handlers = []
     dax.bin.set_logger(logfile, debug=True)
     dax.bin.upload_thread(xnat_host, pindex, alabel, pcount, resdir)
